@@ -71,6 +71,13 @@ mod macros {
     }
 }
 
+#[derive(Debug, Clone, Serialize, Deserialize)]
+pub struct InEntry {
+    pub entity: Option<Address>,
+    pub attribute: String,
+    pub value: EntryValue,
+}
+
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct Entry {
     pub entity: Address,
@@ -129,6 +136,24 @@ impl TryFrom<&InvariantEntry> for Entry {
     }
 }
 
+impl TryFrom<InEntry> for Entry {
+    type Error = anyhow::Error;
+
+    fn try_from(in_entry: InEntry) -> Result<Self, Self::Error> {
+        match in_entry.entity {
+            Some(entity) => Ok(Entry {
+                entity,
+                attribute: in_entry.attribute,
+                value: in_entry.value,
+            }),
+            None => Ok(Entry::try_from(&InvariantEntry {
+                attribute: in_entry.attribute,
+                value: in_entry.value,
+            })?),
+        }
+    }
+}
+
 impl InvariantEntry {
     pub fn entity(&self) -> Result<Address> {
         let mut entity = Cursor::new(vec![0u8; 0]);
