@@ -6,7 +6,7 @@ use crate::database::{
     TYPE_INSTANCED_ATTR, TYPE_IS_ATTR, TYPE_REQUIRES_ATTR,
 };
 use crate::hash::Hashable;
-use crate::jobs::{Job, JobContainer, JobId};
+use crate::jobs::{Job, JobContainer, JobId, State};
 use crate::models;
 use crate::models::File;
 use anyhow::{anyhow, Error, Result};
@@ -363,11 +363,20 @@ pub async fn rescan_vault(
         .add_job(Job::new("REIMPORT", "Reimporting vault..."))
         .unwrap();
 
+    let job_container_rescan = job_container.clone();
     let result =
-        actix_web::web::block(move || _rescan_vault(pool, directory, job_container, job_id)).await;
+        actix_web::web::block(move || _rescan_vault(pool, directory, job_container_rescan, job_id))
+            .await;
+
     if result.is_err() {
         let err = result.err().unwrap();
         error!("Update did not succeed! {:?}", err);
+
+        job_container
+            .write()
+            .unwrap()
+            .update_state(&job_id, State::Failed)
+            .unwrap();
     }
 }
 
