@@ -1,7 +1,7 @@
 use crate::addressing::Address;
 use crate::database::{
     get_latest_files, insert_entry, query, remove_object, retrieve_file, retrieve_object,
-    Addressable, DbPool, Entry, Query,
+    Addressable, DbPool, Entry, InEntry, Query,
 };
 use crate::filesystem::{list_directory, UPath};
 use crate::hash::{decode, encode};
@@ -132,11 +132,21 @@ pub async fn put_object(
         body.extend_from_slice(&chunk);
     }
 
-    let entry = serde_json::from_slice::<Entry>(&body).map_err(ErrorBadRequest)?;
+    let in_entry = serde_json::from_slice::<InEntry>(&body).map_err(ErrorBadRequest)?;
+    let entry = Entry::try_from(in_entry).map_err(ErrorInternalServerError)?;
 
-    let result_address = insert_entry(&connection, entry).map_err(ErrorInternalServerError)?;
+    let result_address =
+        insert_entry(&connection, entry.clone()).map_err(ErrorInternalServerError)?;
 
-    Ok(HttpResponse::Ok().json(result_address))
+    Ok(HttpResponse::Ok().json(
+        [(
+            encode(result_address.encode().map_err(ErrorInternalServerError)?),
+            entry,
+        )]
+        .iter()
+        .cloned()
+        .collect::<HashMap<String, Entry>>(),
+    ))
 }
 
 #[delete("/api/obj/{address_str}")]
