@@ -114,3 +114,11 @@ export function identify(attributes: ComputedRef<[string, IEntry][]>): ComputedR
             }).flat();
     });
 }
+
+export function asDict(attributes: [string, IEntry][]): { [key: string]: string } {
+    const result = {} as { [key: string]: string };
+    attributes.map(([_, attribute]) => attribute).forEach((attribute) => {
+        result[attribute.attribute] = attribute.value.c;
+    });
+    return result;
+}
\ No newline at end of file
